@@ -4,21 +4,34 @@ import subprocess
 import stat
 
 from .common import WHACK_ROOT
+from .files import copy_dir
 
 
 class PackageDeployer(object):
-    def deploy(self, install_dir):
+    def deploy(self, package_dir, target_dir=None):
+        if target_dir is None:
+            install_dir = package_dir
+        else:
+            install_dir = target_dir
+            copy_dir(package_dir, install_dir)
+        
         with open(os.path.join(install_dir, "run"), "w") as run_file:
-            run_file.write('#!/usr/bin/env sh\nexec whack-run-with-whack-root "$(dirname $0)" "$@"')
+            run_file.write(
+                '#!/usr/bin/env sh\n' +
+                'PATH=$(dirname $0)/sbin:$(dirname $0)/bin:$PATH\n' +
+                'exec whack-run "$(dirname $0)" "$@"'
+            )
         subprocess.check_call(["chmod", "+x", os.path.join(install_dir, "run")])
         
-        _create_directly_executable_dir(install_dir, "bin")
-        _create_directly_executable_dir(install_dir, "sbin")
+        whack_root_id = str(uuid.uuid4())
+        
+        _create_directly_executable_dir(install_dir, "bin", whack_root_id)
+        _create_directly_executable_dir(install_dir, "sbin", whack_root_id)
         
         with open(os.path.join(install_dir, ".whack-root-id"), "w") as root_id_file:
-            root_id_file.write(str(uuid.uuid4()))
+            root_id_file.write(whack_root_id)
 
-def _create_directly_executable_dir(install_dir, bin_dir_name):
+def _create_directly_executable_dir(install_dir, bin_dir_name, whack_root_id):
     def install_path(path):
         return os.path.join(install_dir, path)
     
@@ -32,10 +45,10 @@ def _create_directly_executable_dir(install_dir, bin_dir_name):
             with open(bin_file_path, "w") as bin_file:
                 bin_file.write(
                     '#!/usr/bin/env sh\n\n' +
-                    'TARGET="$(dirname $0)/../.{0}/{1}"\n'.format(bin_dir_name, bin_filename) +
-                    'ACTIVE_ROOT_ID_FILE=\'{0}\'\n'.format(WHACK_ROOT) +
-                    'MY_ROOT_ID=`cat $(dirname $0)/../.whack-root-id`\n' +
+                    'ACTIVE_ROOT_ID_FILE=\'{0}\'/.whack-root-id\n'.format(WHACK_ROOT) +
+                    'MY_ROOT_ID=\'{0}\'\n'.format(whack_root_id) +
                     'ACTIVE_ROOT_ID=`cat "$ACTIVE_ROOT_ID_FILE" 2>/dev/null`\n' +
+                    'TARGET="{0}/.{1}/{2}"\n'.format(WHACK_ROOT, bin_dir_name, bin_filename) +
                     'if [ -f "$ACTIVE_ROOT_ID_FILE" ] && [ "$MY_ROOT_ID" = "$ACTIVE_ROOT_ID" ]; then\n' +
                     'exec "$TARGET" "$@"\n' +
                     'else\n' +
